@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1997, 98, 99, 2000 Matthew P. Hodges
+Copyright (C) 1998, 1999, 2000, 2001, 2002, 2004, 2005 Matthew P. Hodges
 This file is part of XMakemol.
 
 XMakemol is free software; you can redistribute it and/or modify
@@ -48,6 +48,7 @@ char * gnu_basename (char *);
 
 void echo_to_message_area(char *);
 void clear_message_area (void);
+void place_dialog_cb (Widget, XtPointer, XtPointer);
 
 #ifdef HAVE_USLEEP
 static int frame_speed = 1;
@@ -236,6 +237,8 @@ make_frame_dlg(Widget parent)
     
   }
 
+  XtAddCallback (frames_dialog, XmNmapCallback, place_dialog_cb, NULL);
+
   XtManageChild(frames_dialog);
   XtPopup(XtParent(frames_dialog), XtGrabNone);
 
