@@ -1,6 +1,6 @@
 /*
   
-Copyright (C) 1997, 98, 99, 2000 Matthew P. Hodges
+Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2005 Matthew P. Hodges
 This file is part of XMakemol.
 
 XMakemol is free software; you can redistribute it and/or modify
@@ -31,6 +31,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "globals.h"
 
+void place_dialog_cb (Widget, XtPointer, XtPointer);
 
 void
 help_cb(Widget widget, XtPointer client_data, XtPointer call_data)
@@ -61,7 +62,7 @@ help_cb(Widget widget, XtPointer client_data, XtPointer call_data)
 }
 
 
-#define ABOUT_MSG "XMakemol version %s\nCopyright (C) 2003 Matthew P. Hodges\n\nXMakemol is free software; you can redistribute it and/or modify\nit under the terms of the GNU General Public License as published by\nthe Free Software Foundation; either version 2, or (at your option)\nany later version.\n\nXMakemol is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with XMakemol; see the file COPYING.  If not, write to the Free Software\nFoundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA"
+#define ABOUT_MSG "XMakemol version %s\nCopyright (C) 2005 Matthew P. Hodges\n\nXMakemol is free software; you can redistribute it and/or modify\nit under the terms of the GNU General Public License as published by\nthe Free Software Foundation; either version 2, or (at your option)\nany later version.\n\nXMakemol is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with XMakemol; see the file COPYING.  If not, write to the Free Software\nFoundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA"
 
 
 void
@@ -171,11 +172,11 @@ make_mouse_dlg(Widget parent)
  
   char *doc_string = NULL;
 
-  static Widget doc_dialog = NULL;
+  static Widget mouse_dialog = NULL;
 
   XmString msg,title;
 
-  if(doc_dialog == NULL)
+  if(mouse_dialog == NULL)
     {
       
       title = XmStringCreateLocalized("Mouse actions");
@@ -192,20 +193,22 @@ make_mouse_dlg(Widget parent)
       msg = XmStringCreateLtoR(doc_string, XmFONTLIST_DEFAULT_TAG);
       XtSetArg(args[n], XmNmessageString, msg); n++;
   
-      doc_dialog =
+      mouse_dialog =
         XmCreateInformationDialog(main_w, "mouse", args, n);
   
       XmStringFree(title);
 
       XtUnmanageChild
-        (XmMessageBoxGetChild(doc_dialog, XmDIALOG_OK_BUTTON));
+        (XmMessageBoxGetChild(mouse_dialog, XmDIALOG_OK_BUTTON));
       
       XtUnmanageChild
-        (XmMessageBoxGetChild(doc_dialog, XmDIALOG_HELP_BUTTON));
+        (XmMessageBoxGetChild(mouse_dialog, XmDIALOG_HELP_BUTTON));
       
     }
   
-  XtManageChild(doc_dialog);
+  XtAddCallback (mouse_dialog, XmNmapCallback, place_dialog_cb, NULL);
+
+  XtManageChild(mouse_dialog);
   
 }
 
