@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1997, 98, 99, 2000 Matthew P. Hodges
+Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2005 Matthew P. Hodges
 This file is part of XMakemol.
 
 XMakemol is free software; you can redistribute it and/or modify
@@ -430,7 +430,7 @@ get_options(int argc, char **argv)
           break;
         case 'v':
           fprintf(stderr, "XMakemol version %s.\n", xmakemol_version);
-          fprintf(stderr, "Copyright (C) 2003 Matthew P. Hodges.\n");
+          fprintf(stderr, "Copyright (C) 2005 Matthew P. Hodges.\n");
           fprintf(stderr, "XMakemol comes with ABSOLUTELY NO WARRANTY.\n");
           fprintf(stderr, "You may redistribute copies of XMakemol\n");
           fprintf(stderr, "under the terms of the GNU General Public License.\n");
@@ -570,3 +570,46 @@ void cleanup_cb(Widget widget, XtPointer client_data, XtPointer call_data)
 
   exit (0);
 }
+
+
+void place_dialog_cb (Widget widget, XtPointer client_data, XtPointer call_data)
+{
+  Dimension pw, w, wmdw, ws;
+  Position px, x;
+
+  XtVaGetValues (main_w,
+                 XmNwidth, &pw,
+                 XmNx, &px,
+                 NULL);
+
+  XtVaGetValues (widget,
+                 XmNwidth, &w,
+                 NULL);
+
+  /* Window manager decoration widths */
+  wmdw = 10;
+
+  ws = WidthOfScreen (XtScreen (widget)); 
+  
+  if ((px + pw + w + (3 * wmdw)) < ws)
+    {
+      /* Place to right of main window */
+      x = px + (pw + (2 * wmdw));
+    }
+  else if (px > (w + (3 * wmdw)))
+    {
+      /* Place to left of main window */
+      x = px - (w + (2 * wmdw));
+    }
+  else
+    {
+      /* Place as far right as possible */
+      x = ws - (w + (2 * wmdw));
+    }
+
+  /* NB: the WM can subvert this, rendering this useless */
+
+  XtVaSetValues (widget,
+                 XmNx, x,
+                 NULL);
+}
